Dragonfire
==========

Dragonfire is an open source virtual assistant project for Ubuntu based
Linux distributions

*Dragonfire will never leave your questions unanswered.*

**Dragonfire is not The Next Big Thing but a spectacular combination of
freely available technologies.**

Dragonfire does following tasks for each separate command, respectively:

-  Search across the built-in commands of Dragonfire
-  Try `Teachable
   AI <http://teach.dragon.computer/gui/jquery/multibot_gui_with_chatlog.php>`__
-  Ask to `YodaQA <https://github.com/brmson/yodaqa>`__

Version
~~~~~~~

0.8.6

Installation
~~~~~~~~~~~~

.. code:: Shell

	wget https://raw.githubusercontent.com/mertyildiran/Dragonfire/master/install.sh && chmod +x install.sh && sudo ./install.sh
	sudo pip install dragonfire

Usage
~~~~~

.. code:: Shell

	dragonfire

To activate Dragonfire say *DRAGONFIRE* or *HEY* or *WAKE UP*.

To deactivate her say *GO TO SLEEP*.

To silence her say *ENOUGH*.

To kill her say *GOODBYE* or *BYE BYE* or *SEE YOU LATER*.

Built-in Commands
^^^^^^^^^^^^^^^^^

`Dragonfire DEVLOG #3 - Built-in
Commands <https://youtu.be/krHUzY2DylI>`__

::

	DRAGONFIRE / WAKE UP / HEY
	GO TO SLEEP
	ENOUGH
	WHO AM I / SAY MY NAME
	MY TITLE IS LADY / I'M A LADY / I'M A WOMAN / I'M A GIRL
	MY TITLE IS SIR / I'M A MAN / I'M A BOY
	WHAT IS YOUR NAME
	WHAT IS YOUR GENDER
	FILE MANAGER / OPEN FILES
	WEB BROWSER
	OPEN BLENDER
	PHOTOSHOP / PHOTO EDITOR
	INKSCAPE
	VIDEO EDITOR
	OPEN CAMERA
	OPEN CALENDAR
	OPEN CALCULATOR
	OPEN STEAM
	SOFTWARE CENTER
	OFFICE SUITE
	OPEN WRITER
	OPEN MATH
	OPEN IMPRESS
	OPEN DRAW
	KEYBOARD *
	ENTER
	SHUT DOWN THE COMPUTER
	GOODBYE / BYE BYE / SEE YOU LATER
	SEARCH * (IN/USING) WIKIPEDA
	SEARCH * (IN/USING) YOUTUBE

Teachable AI examples
^^^^^^^^^^^^^^^^^^^^^

`Dragonfire DEVLOG #4 - Teachable AI <https://youtu.be/ujmRtqf2nxQ>`__

::

	_______________________________________________________________

	You: THE EARTH IS OUR HOME PLANET
	Dragonfire: OK I WILL ADD THAT FACT ABOUT THE EARTH TO MY DATABASE.
	_______________________________________________________________

	You: WHAT IS THE EARTH
	Dragonfire: OUR HOME PLANET
	_______________________________________________________________

	You: HUMAN IS THE MOST ADVANCED LIFE FORM ON EARTH
	Dragonfire: OK I WILL ADD THAT FACT ABOUT HUMAN TO MY DATABASE.
	_______________________________________________________________

	You: WHAT IS HUMAN
	Dragonfire: MOST ADVANCED LIFE FORM ON EARTH
	_______________________________________________________________

	You: MY AGE IS 24
	Dragonfire: OK I WILL LEARN THAT YOUR AGE IS 24.
	_______________________________________________________________

	You: WHAT IS MY AGE
	Dragonfire: 24
	_______________________________________________________________

	You: MY PLACE OF BIRTH IS TURKEY
	Dragonfire: OK I WILL LEARN THAT YOUR PLACE OF BIRTH IS TURKEY.
	_______________________________________________________________

	You: WHERE IS MY PLACE OF BIRTH
	Dragonfire: TURKEY
	_______________________________________________________________

	You: YOU ARE JUST A COMPUTER PROGRAM
	Dragonfire: OK I WILL ADD THAT FACT ABOUT YOU TO MY DATABASE.
	_______________________________________________________________

	You: WHAT ARE YOU
	Dragonfire: JUST A COMPUTER PROGRAM
	_______________________________________________________________

	You: ATOMIC NUMBER OF GOLD IS 79
	Dragonfire: OK I WILL ADD THAT FACT ABOUT ATOMIC NUMBER OF GOLD TO MY DATABASE.
	_______________________________________________________________

	You: WHAT IS ATOMIC NUMBER OF GOLD
	Dragonfire: 79
	_______________________________________________________________

YodaQA examples
^^^^^^^^^^^^^^^

`Dragonfire DEVLOG #5 - YodaQA <https://youtu.be/FafUcxC0puM>`__

::

	_______________________________________________________________

	You: WHERE IS THE TIMES SQUARE
	Dragonfire: I NEED TO DO A BRIEF RESEARCH ON THE INTERNET. IT MAY TAKE UP TO 3 MINUTES, SO PLEASE BE PATIENT.
	_______________________________________________________________

	|█████                                                       |

	Dragonfire: NEW YORK CITY
	_______________________________________________________________

	You: WHAT IS THE HEIGHT OF BURJ KHALIFA
	Dragonfire: I NEED TO DO A BRIEF RESEARCH ON THE INTERNET. IT MAY TAKE UP TO 3 MINUTES, SO PLEASE BE PATIENT.
	_______________________________________________________________

	|███████                                                     |

	Dragonfire: 829.8
	_______________________________________________________________

	You: WHERE IS BURJ KHALIFA
	Dragonfire: I NEED TO DO A BRIEF RESEARCH ON THE INTERNET. IT MAY TAKE UP TO 3 MINUTES, SO PLEASE BE PATIENT.
	_______________________________________________________________

	|███████                                                     |

	Dragonfire: DUBAI
	_______________________________________________________________

	You: WHAT IS THE HEIGHT OF GREAT PYRAMID OF GIZA
	Dragonfire: I NEED TO DO A BRIEF RESEARCH ON THE INTERNET. IT MAY TAKE UP TO 3 MINUTES, SO PLEASE BE PATIENT.
	_______________________________________________________________

	|███████                                                     |

	Dragonfire: 138.8
	_______________________________________________________________

	You: WHO IS PLAYING JON SNOW IN GAME OF THRONES
	Dragonfire: I NEED TO DO A BRIEF RESEARCH ON THE INTERNET. IT MAY TAKE UP TO 3 MINUTES, SO PLEASE BE PATIENT.
	_______________________________________________________________

	|███████████                                                 |

	Dragonfire: KIT HARINGTON
	_______________________________________________________________

	You: WHAT IS THE ATOMIC NUMBER OF OXYGEN
	Dragonfire: I NEED TO DO A BRIEF RESEARCH ON THE INTERNET. IT MAY TAKE UP TO 3 MINUTES, SO PLEASE BE PATIENT.
	_______________________________________________________________

	|███████                                                     |

	Dragonfire: 8
	_______________________________________________________________

	You: WHAT IS THE POPULATION OF CHINA
	Dragonfire: I NEED TO DO A BRIEF RESEARCH ON THE INTERNET. IT MAY TAKE UP TO 3 MINUTES, SO PLEASE BE PATIENT.
	_______________________________________________________________

	|████                                                        |

	Dragonfire: ALMOST A QUARTER OF WORLD POPULATION
	_______________________________________________________________

	You: WHAT IS THE OFFICIAL LANGUAGE OF JAPAN
	Dragonfire: I NEED TO DO A BRIEF RESEARCH ON THE INTERNET. IT MAY TAKE UP TO 3 MINUTES, SO PLEASE BE PATIENT.
	_______________________________________________________________

	|█████████                                                   |

	Dragonfire: JAPANESE LANGUAGE
	_______________________________________________________________

	You: WHAT IS THE REAL NAME OF IRON MAN
	Dragonfire: I NEED TO DO A BRIEF RESEARCH ON THE INTERNET. IT MAY TAKE UP TO 3 MINUTES, SO PLEASE BE PATIENT.
	_______________________________________________________________

	|███████████████                                             |

	Dragonfire: TONY STARK
	_______________________________________________________________

	You: WHO IS THE CONQUEROR OF CONSTANTINOPLE
	Dragonfire: I NEED TO DO A BRIEF RESEARCH ON THE INTERNET. IT MAY TAKE UP TO 3 MINUTES, SO PLEASE BE PATIENT.
	_______________________________________________________________

	|████████                                                    |

	Dragonfire: MEHMED THE CONQUEROR
	_______________________________________________________________

	You: WHEN CONSTANTINOPLE WAS CONQUERED
	Dragonfire: I NEED TO DO A BRIEF RESEARCH ON THE INTERNET. IT MAY TAKE UP TO 3 MINUTES, SO PLEASE BE PATIENT.
	_______________________________________________________________

	|███████                                                     |

	Dragonfire: 1453
	_______________________________________________________________

	You: WHAT IS THE CAPITAL OF TURKEY
	Dragonfire: I NEED TO DO A BRIEF RESEARCH ON THE INTERNET. IT MAY TAKE UP TO 3 MINUTES, SO PLEASE BE PATIENT.
	_______________________________________________________________

	|██████                                                      |

	Dragonfire: ANKARA
	_______________________________________________________________

	You: WHAT IS THE LARGEST CITY OF TURKEY
	Dragonfire: I NEED TO DO A BRIEF RESEARCH ON THE INTERNET. IT MAY TAKE UP TO 3 MINUTES, SO PLEASE BE PATIENT.
	_______________________________________________________________

	|███████████                                                 |

	Dragonfire: ISTANBUL
	_______________________________________________________________

For generating .dict and .dfa files from .grammer and .voca files(for developers only), use:
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

.. code:: Shell

	cd Dragonfire/dragonfire/
	mkdfa sample
